@@ -25,7 +25,6 @@ import (
 	"k8s.io/klog/v2"
 	"k8s.io/kops/upup/pkg/fi"
 	"k8s.io/kops/upup/pkg/fi/cloudup/awsup"
-	"k8s.io/kops/upup/pkg/fi/cloudup/cloudformation"
 	"k8s.io/kops/upup/pkg/fi/cloudup/terraform"
 	"k8s.io/kops/upup/pkg/fi/cloudup/terraformWriter"
 )
@@ -52,8 +51,8 @@ func (e *DHCPOptions) CompareWithID() *string {
 	return e.ID
 }
 
-func (e *DHCPOptions) Find(c *fi.Context) (*DHCPOptions, error) {
-	cloud := c.Cloud.(awsup.AWSCloud)
+func (e *DHCPOptions) Find(c *fi.CloudupContext) (*DHCPOptions, error) {
+	cloud := c.T.Cloud.(awsup.AWSCloud)
 
 	request := &ec2.DescribeDhcpOptionsInput{}
 	if e.ID != nil {
@@ -110,8 +109,8 @@ func (e *DHCPOptions) Find(c *fi.Context) (*DHCPOptions, error) {
 	return actual, nil
 }
 
-func (e *DHCPOptions) Run(c *fi.Context) error {
-	return fi.DefaultDeltaRunMethod(e, c)
+func (e *DHCPOptions) Run(c *fi.CloudupContext) error {
+	return fi.CloudupDefaultDeltaRunMethod(e, c)
 }
 
 func (s *DHCPOptions) CheckChanges(a, e, changes *DHCPOptions) error {
@@ -192,26 +191,3 @@ func (_ *DHCPOptions) RenderTerraform(t *terraform.TerraformTarget, a, e, change
 func (e *DHCPOptions) TerraformLink() *terraformWriter.Literal {
 	return terraformWriter.LiteralProperty("aws_vpc_dhcp_options", *e.Name, "id")
 }
-
-type cloudformationDHCPOptions struct {
-	DomainName        *string             `json:"DomainName,omitempty"`
-	DomainNameServers []string            `json:"DomainNameServers,omitempty"`
-	Tags              []cloudformationTag `json:"Tags,omitempty"`
-}
-
-func (_ *DHCPOptions) RenderCloudformation(t *cloudformation.CloudformationTarget, a, e, changes *DHCPOptions) error {
-	cf := &cloudformationDHCPOptions{
-		DomainName: e.DomainName,
-		Tags:       buildCloudformationTags(e.Tags),
-	}
-
-	if e.DomainNameServers != nil {
-		cf.DomainNameServers = strings.Split(*e.DomainNameServers, ",")
-	}
-
-	return t.RenderResource("AWS::EC2::DHCPOptions", *e.Name, cf)
-}
-
-func (e *DHCPOptions) CloudformationLink() *cloudformation.Literal {
-	return cloudformation.Ref("AWS::EC2::DHCPOptions", *e.Name)
-}
